| Title: | Library Snapshot for Packages and Dependencies in Use by Current Session |
|---|---|
| Description: | Generate a local library copy with relevant packages. All packages currently found within the search path - except base packages - will be copied to the directory provided and can be used later on with the .libPaths() function. |
| Authors: | Peter Meissner [aut, cre] |
| Maintainer: | Peter Meissner <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.3 |
| Built: | 2026-05-14 05:56:36 UTC |
| Source: | https://github.com/petermeissner/librarysnapshot |
Make a local copy of the currently used packages within the session from the currently used library.
library_snapshot(path = NULL, write_list = TRUE, copy.mode = TRUE, exclude_base = TRUE)library_snapshot(path = NULL, write_list = TRUE, copy.mode = TRUE, exclude_base = TRUE)
path |
path to which to copy packages to; if NULL |
write_list |
adds package information csv-file to path; needs path to be set |
copy.mode |
passed through to file.copy |
exclude_base |
should 'base' R packages be excluded or not |
Returns the paths from which packages were copied
## Not run: library_snapshot() library_snapshot(path = tempdir()) ## End(Not run)## Not run: library_snapshot() library_snapshot(path = tempdir()) ## End(Not run)
package_dependencies
package_dependencies(pkg, env = NULL, dependency_type = c("depends", "imports", "linkingto"))package_dependencies(pkg, env = NULL, dependency_type = c("depends", "imports", "linkingto"))
pkg |
the package to resolve dependencies for |
env |
an environment to store results in, is primarily used for recursion |
dependency_type |
the dependency types to include, e.g. "depends", "imports", "linkingto", "suggests" – will leave out suggests by default |
session_dependencies
session_dependencies(exclude_base = TRUE)session_dependencies(exclude_base = TRUE)
exclude_base |
should base and recommended packages be excluded from dependencies? |